@@ -22,7 +22,7 @@ class GapDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         """Gap based data quality scores
 
         Args:
-            series (pd.Series): Series to be analysed
+            series: Series to be analysed
 
         raises:
             UserValueError: If the series has less than 2 values
@@ -47,11 +47,11 @@ class GapDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         """Compute the gap analysis score
 
         Args:
-            analysis_start (pd.Timestamp): Analyis start time
-            analysis_end (pd.Timestamp): Analyis end time
-            gap_detection_method (str): Gap detection method
+            analysis_start: Analyis start time
+            analysis_end: Analyis end time
+            gap_detection_method: Gap detection method
                 Must be one of "iqr", "z_scores", "modified_z_scores"
-            gap_detection_options (dict, optional): Arguments to gap detection method
+            gap_detection_options: Arguments to gap detection method
                 Provided as a keyword dictionary
 
         Returns:
