@@ -30,10 +30,10 @@ def oscillation_detector(data: pd.Series, order: int = 4, threshold: float = 0.2
 
 
     Args:
-        data (pandas.Series): Time series
-        order (int, optional): Polynomial order
+        data: Time series
+        order: Polynomial order
             Order of the prediction polynomial. Defaults to 4.
-        threshold (float, optional): Threshold
+        threshold: Threshold
             Maximum distance of a root to the unit circle for which the signal is considered to have an oscillatory
             component. Defaults to 0.2
 
@@ -141,9 +141,9 @@ def _peak_freq_components(residuals: np.ndarray, data: np.ndarray, dt: float) ->
     Find the peak frequency components of a signal identified as having oscillation via the LPC method.
 
     Args:
-        residuals (np.ndarray): residuals from the predicted LPC analysis.
-        data (np.ndarray): signal. It's assumed the data is uniformly sampled (constant sampling interval)
-        dt (float): sampling interval.
+        residuals: residuals from the predicted LPC analysis.
+        data: signal. It's assumed the data is uniformly sampled (constant sampling interval)
+        dt: sampling interval.
 
     Returns:
         (dict, dict): tuple of two dictionaries where the first contain peak frequencies and amplitudes and the second
@@ -236,8 +236,8 @@ def lpc(y: np.ndarray, order: int) -> np.ndarray:
                vol 28, no. 4, 1980.
 
     Args:
-        y (np.ndarray): Uniformly sampled signal data.
-        order (int): Order of the prediction polynomial. Hence number of LPC coefficients.
+        y: Uniformly sampled signal data.
+        order: Order of the prediction polynomial. Hence number of LPC coefficients.
 
     Returns:
         np.ndarray: LPC coefficients.
@@ -343,8 +343,8 @@ def cross_corr(x: np.ndarray, y: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
     coefficients
 
     Args:
-        x (np.ndarray): Signal 1
-        y (np.ndarray): Signal 2
+        x: Signal 1
+        y: Signal 2
 
     Returns:
         (np.ndarray, np.ndarray): Lags and correlation coefficients
