@@ -12,12 +12,12 @@ def Re(speed: pd.Series, density: float, d_viscosity: float, length_scale: float
     relative internal movement due to different fluid velocities.
 
     Args:
-        speed (pandas.Series): Flow speed.
+        speed: Flow speed.
         density: Density.
             Density of the fluid
-        d_viscosity (float): Dynamic viscosity.
+        d_viscosity: Dynamic viscosity.
             Dynamic viscosity of the fluid
-        length_scale (float): Characteristic length.
+        length_scale: Characteristic length.
             Characteristic linear dimension. A characteristic length is an important dimension that defines the scale
             of a physical system. Often, the characteristic length is the volume of a system divided by its surface
 
