@@ -16,8 +16,8 @@ def Haaland(Re: pd.Series, roughness: float):
     the accuracy of the data.
 
     Args:
-        Re (pandas.Series): Reynolds Number
-        roughness (float) : Surface roughness
+        Re: Reynolds Number
+        roughness: Surface roughness
 
     Returns:
         pandas.Series: Friction factor
