@@ -49,16 +49,16 @@ def retrieve_fluid_properties(
     options as an output for this function. Note that pressure and temperature sensors have to come from the same location.
 
     Args:
-        pressure (pandas.Series): Pressure time series
+        pressure: Pressure time series
             Pressure sensor time series.
-        temperature (pandas.Series): Temperature time series
+        temperature: Temperature time series
             Temperature sensor time series.
-        pvt_data (pandas.DataFrame): PVT data
+        pvt_data: PVT data
             This is a PVT table that has been parse out from a .tab file which is a standardized generated output of
             MultiFlash and PVTSim.
-        param (str): Fluid parameter of interest
+        param: Fluid parameter of interest
             Fluid property to be estimated.
-        interp_method (str): Method
+        interp_method: Method
             The method used to interpolate the pvt table to obtain fluid properties of a given pressure and temperature.
 
     Returns:
