@@ -22,15 +22,15 @@ def calculate_shutin_interval(
     histogram.
 
     Args:
-        shut_valve (pandas.Series): Shut-in valve signal.
+        shut_valve: Shut-in valve signal.
             Shut-in valve signal
-        min_shutin_len (int): Minimum time.
+        min_shutin_len: Minimum time.
             Minimum shut-in length in hours to be considered for detection
-        min_time_btw_shutins (int): Time between.
+        min_time_btw_shutins: Time between.
             Minimum time between consecutive shut-ins in hours to validate change of state
-        shutin_state_below_threshold (bool): Below threshold.
+        shutin_state_below_threshold: Below threshold.
             Indicator to tell the algorithm if the shut-in state is below the threshold
-        shutin_threshold (int): Threshold.
+        shutin_threshold: Threshold.
             Threshold between the valve open and close states. Defaults to None meaning that the threshold is calculated
 
     Returns:
