@@ -27,13 +27,13 @@ def line(
     signal duration is set to 1 day. If no dates are provided, the end date is set to the current date and time.
 
     Args:
-        start_date (pandas.Timestamp): Start date.
+        start_date: Start date.
             The start date of the time series entered as a string, for example: "1975-05-09 20:09:10", or
             "1975-05-09".
-        end_date (pandas.Timestamp): End date.
+        end_date: End date.
             The end date of the time series entered as a string, for example: "1975-05-09 20:09:10", or
             "1975-05-09".
-        sample_freq (pandas.Timedelta): Frequency
+        sample_freq: Frequency
             Sampling frequency as a time delta, value and time unit. Defaults to '1 minute'. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
@@ -44,9 +44,9 @@ def line(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        slope (float): Slope
+        slope: Slope
             Line slope. Defaults to 0 (horizontal line).
-        intercept (float): Intercept
+        intercept: Intercept
              Y-intercept. Defaults to 0.
 
     Returns:
@@ -72,7 +72,7 @@ def const_value(
     number of data points generated is not greater than 100000 with "1 week" sampling resolution.
 
     Args:
-        value (float): Value.
+        value: Value.
                 value. Defaults to 0.
     Returns:
         pandas.Series: Time series.
@@ -105,13 +105,13 @@ def sine_wave(
     1 day. If no dates are provided, the end date is set to the current date and time.
 
     Args:
-        start_date (pandas.Timestamp): Start date
+        start_date: Start date
             Date-time string when the time series starts. The date must be a string, for example:
             "1975-05-09 20:09:10".
-        end_date (pandas.Timestamp): End date
+        end_date: End date
             Date-time string when the time series starts. The date must be a string, for example:
             "1975-05-09 20:09:10".
-        sample_freq (pd.Timedelta): Frequency
+        sample_freq: Frequency
             Sampling frequency as a time delta, value and time unit. Defaults to '1 minute'. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
@@ -122,7 +122,7 @@ def sine_wave(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        wave_period (pd.Timedelta): Wave period
+        wave_period: Wave period
             The time it takes for two successive crests (one wavelength) to pass a specified point. For example, defining
             a wave period of :math:`10 min` will generate one full wave every 10 minutes. The period can not be 0. If
             no value is provided, it 1 minute. Valid time units are:
@@ -135,11 +135,11 @@ def sine_wave(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        wave_mean (float): Mean
+        wave_mean: Mean
             The wave's mean value. Defaults to 0.
-        wave_amplitude (float): Peak amplitude
+        wave_amplitude: Peak amplitude
             Maximum absolute deviation from the mean. Defaults to 1.
-        wave_phase (float): Phase
+        wave_phase: Phase
             Specifies (in radians) where in its cycle the oscillation is at time = 0. When the phase is non-zero, the
             wave is shifted in time. A negative value represents a delay, and a positive value represents an advance.
             Defualts to 0.
@@ -170,8 +170,8 @@ def _get_sample_frequency(sample_freq: float, unit: TimeUnits):
     Helper method to convert the frequency magnitude and units into a string that is then used by other function
     to generate DatetimeIndex data
     Args:
-        sample_freq (float): Frequency magnitude
-        unit (TimeUnits): Time unit
+        sample_freq: Frequency magnitude
+        unit: Time unit
             Valid values "ns|us|ms|s|m|h|D|W". Default is "m" (minutes)
 
     Returns:
@@ -198,8 +198,8 @@ def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     with a mean of zero and a given standard deviation (magnitude) in seconds.
 
     Args:
-        data (pd.Series): Time series
-        magnitude (float, optional): Magnitude
+        data: Time series
+        magnitude: Magnitude
             Time delta perturbation magnitude in seconds. If none is given, it is set to the inferred average sampling
             rate in seconds of the original signal.
 
@@ -247,13 +247,13 @@ def insert_data_gaps(
     is defined by the given 'fraction' relative to the original time series.
 
     Args:
-        data (pandas.Series): Time series
-        fraction (float): Remove fraction
+        data: Time series
+        fraction: Remove fraction
             Fraction of data points to remove relative to the original time series. Must be a number higher than 0 and
             lower than 1 (0 < keep < 1). Defaults to 0.25.
-        num_gaps (int, Optional): Number of gaps
+        num_gaps: Number of gaps
             Number of gaps to generate. Only needs to be provided when using the "Multiple" gaps method.
-        data_buffer (int): Buffer
+        data_buffer: Buffer
             Minimum of data points to keep between data gaps and at the start and end of the time series. If the buffer
             of data points is higher than 1% of the number of data points in the time series, the end and start buffer
             is set to 1% of the total available data points.
@@ -473,9 +473,9 @@ def _make_index(
     Returns:
 
     Args:
-        start (pd.Timestamp, Optional): Start date-time
-        end (pd.Timestamp, Optional): End date-time
-        freq (str, Optional): Frequency
+        start: Start date-time
+        end: End date-time
+        freq: Frequency
             Sample frequency in time units, for example '3 h' represents 3 hours.
 
     Returns:
