@@ -14,12 +14,12 @@ def white_noise(
     Adds white noise to the original data using a given signal-to-noise ratio (SNR).
 
     Args:
-        data (pandas.Series): Time series
-        snr_db (float): SNR
+        data: Time series
+        snr_db: SNR
             Signal-to-noise ratio (SNR) in decibels. SNR is a comparison of the level of a signal to the level of
             background noise. SNR is defined as the ratio of signal power to the noise power. A ratio higher than 1
             indicates more signal than noise. Defaults to 30.
-        seed (Optional, int): Seed
+        seed: Seed
             A seed (integer number) to initialize the random number generator. If left empty, then a fresh,
             unpredictable values will be generated. If a value is entered the exact random noise will be generated if
             the time series data and date range is not changed.
