@@ -18,12 +18,12 @@ def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: flo
     user defined.
 
     Args:
-        data (pandas.Series): Time series.
-        window (int, optional): Window size.
+        data: Time series.
+        window: Window size.
             Defaults to 10 data points or time steps for uniformly sample time series.
-        sigma (float, optional): Sigma.
+        sigma: Sigma.
             Parameter that controls the width of the Gaussian filter. Defaults to 6.
-        offset_factor (int, optional): Offset factor.
+        offset_factor: Offset factor.
             Parameter that controls the magnitude of the weights for each past observation within the window.
             Defaults to 0.75.
 
@@ -57,8 +57,8 @@ def calculate_alma(values: List, weights: np.ndarray):
     """Calculate alma value for a window time.
 
     Args:
-        values (List): Datapoints in the window time.
-        weights (numpy.ndarray): Weights to calculate Alma value.
+        values: Datapoints in the window time.
+        weights: Weights to calculate Alma value.
 
     Returns:
         float: Calculated Alma value.
