@@ -29,18 +29,18 @@ def chebyshev(
     the passband (Wikipedia).
 
     Args:
-        data (pandas.DataFrame or pandas.Series): Time series.
-        filter_type (int, optional): Filter type
+        data: Time series.
+        filter_type: Filter type
             Options are 1 or 2. Defaults to 1.
-        N (int, optional): Order
+        N: Order
             Defaults to 10.
-        rp (float, optional): Maximum ripple.
+        rp: Maximum ripple.
             Maximum ripple allowed below unity gain in the passband.
             Defaults to 0.1.
-        Wn (float, optional): Critical frequency.
+        Wn: Critical frequency.
             Number between 0 and 1, with 1 representing one-half of the sampling rate (Nyquist frequency).
             Defaults to 0.1.
-        btype (str, optional): Filter type
+        btype: Filter type
             The options are: "lowpass" and "highpass"
             Defaults to "lowpass".
 
