@@ -13,12 +13,12 @@ def sma(data: pd.Series, time_window: str = "60min", min_periods: int = 1) -> pd
     SMA time series are much less noisy than the original time series. However, SMA time series lag the original time series, which means that changes in the trend are only seen with a delay (lag) of time_window/2.
 
     Args:
-        data (pandas.Series): Time series.
-        time_window (str, optional): Window
+        data: Time series.
+        time_window: Window
             Length of the time period to compute the average. Defaults to '60min'.
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
             If the user gives a number without unit (such as '60'), it will be considered as the number of minutes.
-        min_periods (int, optional): Minimum samples.
+        min_periods: Minimum samples.
             Minimum number of observations in window required to have a value (otherwise result is NA). Defaults  to 1.
 
     Returns:
