@@ -23,9 +23,7 @@ from .utility_functions import (
     bin_map,
     ceil,
     clip,
-    create_series_from_timesteps,
     floor,
-    generate_step_series,
     get_timestamps,
     maximum,
     minimum,
