@@ -75,9 +75,9 @@ def above_below(series: pd.Series, upper_limit: float, lower_limit: float):
     Count the number of points above/below upper_limit/lower_limit.
 
     Args:
-        series (pandas.Series): Data with a pandas.DatetimeIndex.
-        upper_limit (float): Value for upper limit.
-        lower_limit (float): Value for lower limit.
+        series: Data with a pandas.DatetimeIndex.
+        upper_limit: Value for upper limit.
+        lower_limit: Value for lower limit.
 
     Returns:
         dict: The numbers above/below upper_limit/lower_limit.
@@ -96,8 +96,8 @@ def num_vals_in_boxes(series: pd.Series, num_boxes: int):
     """Count the number of points in each of the boxes between 0 and 100 %.
 
     Args:
-        series (pandas.Series): Data with a pandas.DatetimeIndex.
-        num_boxes (int): Number of boxes.
+        series: Data with a pandas.DatetimeIndex.
+        num_boxes: Number of boxes.
 
     Returns:
         dict: A list with the number of points in each box in keyword "data".
@@ -126,8 +126,8 @@ def functional_mean(function: Callable, x_vals: List) -> np.ndarray:
     input and output lists to have the same lengths.
 
     Args:
-        function (Callable): Function used to calculate the mean.
-        x_vals (List): Data values used to calculate the mean of a function.
+        function: Function used to calculate the mean.
+        x_vals: Data values used to calculate the mean of a function.
 
     Raises:
         RuntimeError: Checks that x_vals is not empty.
@@ -151,7 +151,7 @@ def is_na_all(data: Union[pd.DataFrame, pd.Series]) -> bool:
     """Convenience method to test if all values in dataframe/series are NaN.
 
     Args:
-        data (Union[pandas.DataFrame, pandas.Series]): Input data.
+        data: Input data.
 
     Raises:
         UserValueError: Checks that the data type for the input data is pandas.DataFrame or pandas.Series.
@@ -172,8 +172,8 @@ def gaps_detector(timestamps: np.ndarray, threshold: int = 86400) -> np.ndarray:
     Taken from: https://github.com/cognitedata/data-quality-functions/blob/master/functions/completeness/function/completeness.py
 
     Args:
-        timestamps (numpy.ndarray): Time array_like.
-        threshold (int, optional): Threshold for gaps. Defaults to 86400 seconds, i.e one full day in epoch time.
+        timestamps: Time array_like.
+        threshold: Threshold for gaps. Defaults to 86400 seconds, i.e one full day in epoch time.
     Returns:
         numpy.ndarray: 2D array of begin and end time of gaps in seconds epoch time.
     """
@@ -189,8 +189,8 @@ def gaps_detector(timestamps: np.ndarray, threshold: int = 86400) -> np.ndarray:
 def check_uniform(data: pd.DataFrame, unit: str = "ns") -> bool:
     """Convenience method to verify input time series is uniform.
     Args:
-        data (pandas.DataFrame): Time series to check. Object must have a datetime-like index.
-        unit (str, optional): Time unit of uniformity check. Follows Numpy DateTime Units convention. Defaults to "ns".
+        data: Time series to check. Object must have a datetime-like index.
+        unit: Time unit of uniformity check. Follows Numpy DateTime Units convention. Defaults to "ns".
     Returns:
         bool: True if input timeseries is uniform, False if not uniform.
     """
@@ -206,8 +206,8 @@ def make_uniform(data: pd.DataFrame, resolution: str = "1s", interpolation: str
     """Convenience method to make an input time series dataframe uniform per specified temporal resolution.
     Object must have a datetime-like index.
     Args:
-        resolution (str):  Temporal resolution of uniform time series. Follows Pandas DateTime convention. Defaults to "1s".
-        interpolation (str, optional): Method for optional interpolation. Follows pandas Resampler.interpolate. Defaults to None.
+        resolution: Temporal resolution of uniform time series. Follows Pandas DateTime convention. Defaults to "1s".
+        interpolation: Method for optional interpolation. Follows pandas Resampler.interpolate. Defaults to None.
     Returns:
         pandas.DataFrame: Uniform Timeseries DataFrame.
     """
@@ -224,10 +224,10 @@ def time_parse(time_window: str = "60min", function_name: str = "") -> pd.Timede
     """Check that time_window is given in a correct format.
 
     Args:
-        time_window (str, optional): Time window input. Defaults to "60min".
+        time_window: Time window input. Defaults to "60min".
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
             If the user gives a number without unit (such as '60'), it will be considered as the number of minutes.
-        function_name (str, optional): Prints the name of the function that called time_parse in the error message if an error is raised. Defaults to "".
+        function_name: Prints the name of the function that called time_parse in the error message if an error is raised. Defaults to "".
 
     Raises:
         UserValueError: Raise a value error if time_window is given in a wrong format.
@@ -253,8 +253,8 @@ def time_to_points(data: pd.Series, time_window="60min") -> int:
     """Find the average number of points given a time window.
 
     Args:
-        data (pandas.Series): Data with a pandas.DatetimeIndex.
-        time_window (str, optional): Length of the time period to compute the average of points. Defaults to "60min".
+        data: Data with a pandas.DatetimeIndex.
+        time_window: Length of the time period to compute the average of points. Defaults to "60min".
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
 
     Returns:
@@ -276,11 +276,11 @@ def fill_gaps(
     """Mask nan/fill gaps bases on the time size of missing data
 
     Args:
-        data (pandas.Series): Time series to impute.
-        granularity (str, optional): Temporal resolution of uniform time series, before resampling. Defaults to None.
-        ffill_resolution (str, optional): Gaps smaller than this will be filled with method. Defaults to None.
-        interpolate_resolution (str, optional): Gaps smaller than this will be interpolated, larger than this will be filled by noise. Defaults to None.
-        method (str, optional): Method used to fill nan. Defaults to 'ffill', but ‘backfill’, ‘bfill’ and ‘pad’ can also be used.
+        data: Time series to impute.
+        granularity: Temporal resolution of uniform time series, before resampling. Defaults to None.
+        ffill_resolution: Gaps smaller than this will be filled with method. Defaults to None.
+        interpolate_resolution: Gaps smaller than this will be interpolated, larger than this will be filled by noise. Defaults to None.
+        method: Method used to fill nan. Defaults to 'ffill', but ‘backfill’, ‘bfill’ and ‘pad’ can also be used.
     Returns:
         pandas.DataFrame or pd.Series: Uniform, time series without nan values.
     """
