@@ -25,7 +25,7 @@ def round(x, decimals: int):
 
     Args:
         x: time series
-        decimals (int): number of decimals
+        decimals: number of decimals
 
     Returns:
         pd.Series: time series
@@ -80,9 +80,9 @@ def clip(x, low: float = -np.inf, high: float = np.inf):
 
     Args:
         x (pd.Series): time series
-        low (float, Optional): Lower limit
+        low: Lower limit
             Lower clipping limit. Default: -infinity
-        high (float, Optional): Upper limit
+        high: Upper limit
             Upper clipping limit. Default: +infinity
 
     Returns:
@@ -99,7 +99,7 @@ def maximum(x1, x2, align_timesteps: bool = False):
     Args:
         x1: First time series or number
         x2: Second time series or number
-        align_timesteps (bool) : Auto-align
+        align_timesteps: Auto-align
           Automatically align time stamp  of input time series. Default is False.
 
     Returns:
@@ -117,7 +117,7 @@ def minimum(x1, x2, align_timesteps: bool = False):
     Args:
         x1: First time series or number
         x2: Second time series or number
-        align_timesteps (bool) : Auto-align
+        align_timesteps: Auto-align
           Automatically align time stamp  of input time series. Default is False.
 
     Returns:
@@ -134,8 +134,8 @@ def union(series1: pd.Series, series2: pd.Series) -> pd.Series:
     occurs in both series, the value of the first time series is used.
 
     Args:
-        series1 (pd.Series): time series
-        series2 (pd.Series): time series
+        series1: time series
+        series2: time series
 
     Returns:
         pd.Series: time series
@@ -156,7 +156,7 @@ def bin_map(x1, x2, align_timesteps: bool = False):
     Args:
         x1: First time series or number
         x2: Second time series or number
-        align_timesteps (bool): Auto-align
+        align_timesteps: Auto-align
           Automatically align time stamp  of input time series. Default is False.
 
     Returns:
@@ -176,9 +176,9 @@ def set_timestamps(timestamp_series: pd.Series, value_series: pd.Series, unit: T
 
 
     Args:
-        timestamp_series (pd.Series): Timestamp time series
-        value_series (pd.Series): Value time series
-        unit (str): Timestamp unit
+        timestamp_series: Timestamp time series
+        value_series: Value time series
+        unit: Timestamp unit
           Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
 
     Returns:
@@ -206,8 +206,8 @@ def get_timestamps(series: pd.Series, unit: TimeUnits = "ms") -> pd.Series:
     nanoseconds may happen if unit is not nanoseconds.
 
     Args:
-        series (pd.Series): Time-series
-        unit (str): Timestamp unit
+        series: Time-series
+        unit: Timestamp unit
           Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
 
     Returns:
@@ -232,10 +232,10 @@ def time_shift(series: pd.Series, n_units: float = 0, unit: TimeUnits = "ms") ->
     Shift time series by a time period
 
     Args:
-        series (pd.Series): Time-series
-        n_units (float): Time periods to shift
+        series: Time-series
+        n_units: Time periods to shift
             Number of time periods to shift
-        unit (str): Time period unit
+        unit: Time period unit
           Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
 
     Returns:
@@ -259,11 +259,11 @@ def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value:
     Undefined and infinity values can be replaced by using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
 
     Args:
-        series (pd.Series): Time series
-        to_replace (List[float], optional): Replace
+        series: Time series
+        to_replace: Replace
             List of values to replace. The values must be seperated by semicolons. Infinity and undefined values can be
             replaced by using the keywords inf, -inf and nan. The default is to replace no values.
-        value (float, optional): By
+        value: By
             Value used as replacement. Default is 0.0
 
     Returns:
@@ -288,8 +288,8 @@ def remove(series: pd.Series, to_remove: Optional[List[float]] = None):
 
 
     Args:
-        series (pd.Series): Time series
-        to_remove (List[float], optional): Remove
+        series: Time series
+        to_remove: Remove
             List of values to remove. The values must be seperated by semicolons. Infinity and undefined values can be
             replaced by using the keywords inf, -inf and nan.
 
@@ -312,10 +312,10 @@ def threshold(series: pd.Series, low: float = -np.inf, high: float = np.inf):
     is 1.0 if the input is between the (inclusive) limits, and 0.0 otherwise.
 
     Args:
-        series (pd.Series): Time series
-        low (float, Optional): Lower limit
+        series: Time series
+        low: Lower limit
            threshold. Default: -infinity
-        high (float, Optional): Upper limit
+        high: Upper limit
            threshold. Default: +infinity
 
     Returns:
@@ -333,7 +333,7 @@ def generate_step_series(flag: pd.Series) -> pd.Series:
     Construct a step-wise time series (with 0-1 values) from a flag time series.
 
     Args:
-        flag (pd.Series): Binary time series.
+        flag: Binary time series.
             The length of the flag time series has to be the same as the original data points.
 
     Returns:
@@ -406,7 +406,7 @@ def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
     with the provided timesteps in seconds. All values of the output series are zero.
 
     Args:
-        timesteps (List[timedelta]): Time steps between points.
+        timesteps: Time steps between points.
 
     Returns:
         pd.Series: Time series
@@ -429,14 +429,14 @@ def normality_assumption_test(
     This function performs a Shapiro-Wilk test to check if the data is normally distributed.
 
     Args:
-        series (pd.Series): Time series
-        max_data_points (int, optional): Maximum number of data points.
+        series: Time series
+        max_data_points: Maximum number of data points.
             The test is only performed if the time series contains less data points than this value.
             Default to 5000.
-        min_p_value (float, optional): Minimum p value.
+        min_p_value: Minimum p value.
             Probability of the time series not being normally distributed.
             Default to 0.5.
-        min_W (float, optional): Minimum W value.
+        min_W: Minimum W value.
             W is between 0 and 1, small values lead to a rejection of the
             normality assumption. Ref: https://www.nrc.gov/docs/ML1714/ML17143A100.pdf
             Default to 0.5.
@@ -461,10 +461,10 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
     This functions performs a z-scores test given a cutoff value and returns a binary time series.
 
     Args:
-        x (np.array): Data values.
-        cutoff (float, optional): Cut-off
+        x: Data values.
+        cutoff: Cut-off
             Number of standard deviations from the mean.
-        direction (str, optional): Direction of the test.
+        direction: Direction of the test.
             Options:
                 "greater": the function will check if the z-scores are greater than the cutoff
                 "less": the function will check if the z-scores are less than the cutoff
@@ -488,9 +488,9 @@ def modified_z_scores_test(
     This functions performs a modified z-scores test given a cutoff value and returns a binary time series.
 
     Args:
-        x (np.array): Data values.
-        cutoff (float, optional): Cut-off value.
-        direction (str, optional): Direction of the test.
+        x: Data values.
+        cutoff: Cut-off value.
+        direction: Direction of the test.
             Options:
                 "greater": the function will check if the modified z-scores are greater than the cutoff
                 "less": the function will check if the modified z-scores are less than the cutoff
@@ -516,9 +516,9 @@ def iqr_test(
     This functions performs a iqr test and returns a binary time series.
 
     Args:
-        x (np.array): Data values.
-        limit (str, optional): Cut off limit.
-        direction (str, optional): Direction of the test.
+        x: Data values.
+        limit: Cut off limit.
+        direction: Direction of the test.
             Options:
                 "greater": the function will check if the values are greater than the cutoff limit.
                 "less": the function will check if the values are less than the cutoff limit.
@@ -545,9 +545,9 @@ def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "le
     This functions performs a threshold test based on a direction (greater than or less than).
 
     Args:
-        x (np.array): Data values.
-        cutoff (float): Cut-off value.
-        direction (str): Direction of the test.
+        x: Data values.
+        cutoff: Cut-off value.
+        direction: Direction of the test.
             Options:
                 "greater": the function will check if the values are greater than the cutoff limit.
                 "less": the function will check if the values are less than the cutoff limit.
